@@ -39,7 +39,7 @@ Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 #include "bgpd/bgp_ecommunity.h"
 
 /* Attribute strings for logging. */
-static struct message attr_str [] = 
+static const struct message attr_str [] = 
 {
   { BGP_ATTR_ORIGIN,           "ORIGIN" }, 
   { BGP_ATTR_AS_PATH,          "AS_PATH" }, 
@@ -61,9 +61,9 @@ static struct message attr_str [] =
   { BGP_ATTR_AS4_AGGREGATOR,   "AS4_AGGREGATOR" }, 
   { BGP_ATTR_AS_PATHLIMIT,     "AS_PATHLIMIT" },
 };
-int attr_str_max = sizeof(attr_str)/sizeof(attr_str[0]);
+static const int attr_str_max = sizeof(attr_str)/sizeof(attr_str[0]);
 
-struct hash *cluster_hash;
+static struct hash *cluster_hash;
 
 static void *
 cluster_hash_alloc (void *p)
@@ -153,8 +153,7 @@ cluster_dup (struct cluster_list *cluster)
 {
   struct cluster_list *new;
 
-  new = XMALLOC (MTYPE_CLUSTER, sizeof (struct cluster_list));
-  memset (new, 0, sizeof (struct cluster_list));
+  new = XCALLOC (MTYPE_CLUSTER, sizeof (struct cluster_list));
   new->length = cluster->length;
 
   if (cluster->length)
@@ -201,7 +200,7 @@ cluster_init (void)
 }
 
 /* Unknown transit attribute. */
-struct hash *transit_hash;
+static struct hash *transit_hash;
 
 static void
 transit_free (struct transit *transit)
@@ -275,13 +274,13 @@ transit_hash_cmp (const void *p1, const void *p2)
 }
 
 static void
-transit_init ()
+transit_init (void)
 {
   transit_hash = hash_create (transit_hash_key_make, transit_hash_cmp);
 }
 
 /* Attribute hash routines. */
-struct hash *attrhash;
+static struct hash *attrhash;
 
 static struct attr_extra *
 bgp_attr_extra_new (void)
@@ -857,7 +856,7 @@ static int bgp_attr_aspath_check( struct peer *peer,
 	  && ! aspath_firstas_check (attr->aspath, peer->as))
  	{
  	  zlog (peer->log, LOG_ERR,
- 		"%s incorrect first AS (must be %d)", peer->host, peer->as);
+ 		"%s incorrect first AS (must be %u)", peer->host, peer->as);
  	  bgp_notify_send (peer,
  			   BGP_NOTIFY_UPDATE_ERR,
  			   BGP_NOTIFY_UPDATE_MAL_AS_PATH);
@@ -1495,10 +1494,7 @@ bgp_attr_unknown (struct peer *peer, struct attr *attr, u_char flag,
 
   /* Store transitive attribute to the end of attr->transit. */
   if (! ((attre = bgp_attr_extra_get(attr))->transit) )
-    {
-      attre->transit = XMALLOC (MTYPE_TRANSIT, sizeof (struct transit));
-      memset (attre->transit, 0, sizeof (struct transit));
-    }
+      attre->transit = XCALLOC (MTYPE_TRANSIT, sizeof (struct transit));
 
   transit = attre->transit;
 
