@@ -26,7 +26,7 @@ Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 #include "bgpd/bgp_community.h"
 
 /* Hash of community attribute. */
-struct hash *comhash;
+static struct hash *comhash;
 
 /* Allocate a new communities value.  */
 static struct community *
@@ -78,7 +78,7 @@ community_del_val (struct community *com, u_int32_t *val)
 	  c = com->size -i -1;
 
 	  if (c > 0)
-	    memcpy (com->val + i, com->val + (i + 1), c * sizeof (val));
+	    memcpy (com->val + i, com->val + (i + 1), c * sizeof (*val));
 
 	  com->size--;
 
@@ -282,7 +282,7 @@ community_com2str  (struct community *com)
 	default:
 	  as = (comval >> 16) & 0xFFFF;
 	  val = comval & 0xFFFF;
-	  sprintf (pnt, "%d:%d", as, val);
+	  sprintf (pnt, "%u:%d", as, val);
 	  pnt += strlen (pnt);
 	  break;
 	}
@@ -617,7 +617,7 @@ community_str2com (const char *str)
 
 /* Return communities hash entry count.  */
 unsigned long
-community_count ()
+community_count (void)
 {
   return comhash->count;
 }
