@@ -901,8 +901,8 @@ bgp_ignore (struct peer *peer)
 }
 
 /* Finite State Machine structure */
-struct {
-  int (*func) ();
+static const struct {
+  int (*func) (struct peer *);
   int next_state;
 } FSM [BGP_STATUS_MAX - 1][BGP_EVENTS_MAX - 1] = 
 {
