@@ -813,7 +813,7 @@ bgp_open_send (struct peer *peer)
   length = bgp_packet_set_size (s);
 
   if (BGP_DEBUG (normal, NORMAL))
-    zlog_debug ("%s sending OPEN, version %d, my as %d, holdtime %d, id %s", 
+    zlog_debug ("%s sending OPEN, version %d, my as %u, holdtime %d, id %s", 
 	       peer->host, BGP_VERSION_4, local_as,
 	       send_holdtime, inet_ntoa (peer->local_id));
 
@@ -1184,7 +1184,7 @@ bgp_open_receive (struct peer *peer, bgp_size_t size)
 
   /* Receive OPEN message log  */
   if (BGP_DEBUG (normal, NORMAL))
-    zlog_debug ("%s rcv OPEN, version %d, remote-as (in open) %d,"
+    zlog_debug ("%s rcv OPEN, version %d, remote-as (in open) %u,"
                 " holdtime %d, id %s",
 	        peer->host, version, remote_as, holdtime,
 	        inet_ntoa (remote_id));
@@ -1277,7 +1277,7 @@ bgp_open_receive (struct peer *peer, bgp_size_t size)
 	  else
 	    {
 	      if (BGP_DEBUG (normal, NORMAL))
-		zlog_debug ("%s bad OPEN, remote AS is %d, expected %d",
+		zlog_debug ("%s bad OPEN, remote AS is %u, expected %u",
 			    peer->host, remote_as, peer->as);
 	      bgp_notify_send_with_data (peer, BGP_NOTIFY_OPEN_ERR,
 					 BGP_NOTIFY_OPEN_BAD_PEER_AS,
@@ -1304,8 +1304,8 @@ bgp_open_receive (struct peer *peer, bgp_size_t size)
 	}
 	else if (ret == 0 && realpeer->status != Active
 	         && realpeer->status != OpenSent
-		 && realpeer->status != OpenConfirm)
-
+		 && realpeer->status != OpenConfirm
+		 && realpeer->status != Connect)
  	{
  	  /* XXX: This is an awful problem.. 
  	   *
@@ -1363,8 +1363,9 @@ bgp_open_receive (struct peer *peer, bgp_size_t size)
  	}
 
       if (BGP_DEBUG (events, EVENTS))
-	zlog_debug ("%s [Event] Transfer temporary BGP peer to existing one",
-		   peer->host);
+	zlog_debug ("%s [Event] Transfer accept BGP peer to real (state %s)",
+		   peer->host, 
+		   LOOKUP (bgp_status_msg, realpeer->status));
 
       bgp_stop (realpeer);
       
@@ -1430,7 +1431,7 @@ bgp_open_receive (struct peer *peer, bgp_size_t size)
   if (remote_as != peer->as)
     {
       if (BGP_DEBUG (normal, NORMAL))
-	zlog_debug ("%s bad OPEN, remote AS is %d, expected %d",
+	zlog_debug ("%s bad OPEN, remote AS is %u, expected %u",
 		   peer->host, remote_as, peer->as);
       bgp_notify_send_with_data (peer, 
 				 BGP_NOTIFY_OPEN_ERR, 
@@ -2207,7 +2208,10 @@ bgp_capability_msg_parse (struct peer *peer, u_char *pnt, bgp_size_t length)
   return 0;
 }
 
-/* Dynamic Capability is received. */
+/* Dynamic Capability is received. 
+ *
+ * This is exported for unit-test purposes
+ */
 int
 bgp_capability_receive (struct peer *peer, bgp_size_t size)
 {
