@@ -422,7 +422,7 @@ if_flag_dump (unsigned long flag)
 
 /* For debugging */
 static void
-if_dump (struct interface *ifp)
+if_dump (const struct interface *ifp)
 {
   struct listnode *node;
   struct connected *c;
@@ -444,7 +444,7 @@ if_dump (struct interface *ifp)
 
 /* Interface printing for all interface. */
 void
-if_dump_all ()
+if_dump_all (void)
 {
   struct listnode *node;
   void *p;
@@ -620,9 +620,7 @@ DEFUN (show_address,
 struct connected *
 connected_new (void)
 {
-  struct connected *new = XMALLOC (MTYPE_CONNECTED, sizeof (struct connected));
-  memset (new, 0, sizeof (struct connected));
-  return new;
+  return XCALLOC (MTYPE_CONNECTED, sizeof (struct connected));
 }
 
 /* Free connected structure. */
