@@ -272,7 +272,7 @@ vtysh_pager_init (void)
 }
 
 /* Command execution over the vty interface. */
-static void
+static int
 vtysh_execute_func (const char *line, int pager)
 {
   int ret, cmd_stat;
@@ -288,7 +288,7 @@ vtysh_execute_func (const char *line, int pager)
   vline = cmd_make_strvec (line);
 
   if (vline == NULL)
-    return;
+    return CMD_SUCCESS;
 
   saved_ret = ret = cmd_execute_command (vline, vty, &cmd, 1);
   saved_node = vty->node;
@@ -336,6 +336,7 @@ vtysh_execute_func (const char *line, int pager)
 
   cmd_free_strvec (vline);
 
+  cmd_stat = ret;
   switch (ret)
     {
     case CMD_WARNING:
@@ -394,7 +395,7 @@ vtysh_execute_func (const char *line, int pager)
 			  }
 			fp = NULL;
 		      }
-		    return;
+		    return CMD_SUCCESS;
 		  }
 
 		ret = cmd_execute_command (vline, vty, &cmd, 1);
@@ -435,18 +436,19 @@ vtysh_execute_func (const char *line, int pager)
 	}
       fp = NULL;
     }
+  return cmd_stat;
 }
 
-void
+int
 vtysh_execute_no_pager (const char *line)
 {
-  vtysh_execute_func (line, 0);
+  return vtysh_execute_func (line, 0);
 }
 
-void
+int
 vtysh_execute (const char *line)
 {
-  vtysh_execute_func (line, 1);
+  return vtysh_execute_func (line, 1);
 }
 
 /* Configration make from file. */
@@ -711,97 +713,97 @@ vtysh_completion (char *text, int start, int end)
 #endif
 
 /* Vty node structures. */
-struct cmd_node bgp_node =
+static struct cmd_node bgp_node =
 {
   BGP_NODE,
   "%s(config-router)# ",
 };
 
-struct cmd_node rip_node =
+static struct cmd_node rip_node =
 {
   RIP_NODE,
   "%s(config-router)# ",
 };
 
-struct cmd_node isis_node =
+static struct cmd_node isis_node =
 {
   ISIS_NODE,
   "%s(config-router)# ",
 };
 
-struct cmd_node interface_node =
+static struct cmd_node interface_node =
 {
   INTERFACE_NODE,
   "%s(config-if)# ",
 };
 
-struct cmd_node rmap_node =
+static struct cmd_node rmap_node =
 {
   RMAP_NODE,
   "%s(config-route-map)# "
 };
 
-struct cmd_node zebra_node =
+static struct cmd_node zebra_node =
 {
   ZEBRA_NODE,
   "%s(config-router)# "
 };
 
-struct cmd_node bgp_vpnv4_node =
+static struct cmd_node bgp_vpnv4_node =
 {
   BGP_VPNV4_NODE,
   "%s(config-router-af)# "
 };
 
-struct cmd_node bgp_ipv4_node =
+static struct cmd_node bgp_ipv4_node =
 {
   BGP_IPV4_NODE,
   "%s(config-router-af)# "
 };
 
-struct cmd_node bgp_ipv4m_node =
+static struct cmd_node bgp_ipv4m_node =
 {
   BGP_IPV4M_NODE,
   "%s(config-router-af)# "
 };
 
-struct cmd_node bgp_ipv6_node =
+static struct cmd_node bgp_ipv6_node =
 {
   BGP_IPV6_NODE,
   "%s(config-router-af)# "
 };
 
-struct cmd_node bgp_ipv6m_node =
+static struct cmd_node bgp_ipv6m_node =
 {
   BGP_IPV6M_NODE,
   "%s(config-router-af)# "
 };
 
-struct cmd_node ospf_node =
+static struct cmd_node ospf_node =
 {
   OSPF_NODE,
   "%s(config-router)# "
 };
 
-struct cmd_node ripng_node =
+static struct cmd_node ripng_node =
 {
   RIPNG_NODE,
   "%s(config-router)# "
 };
 
-struct cmd_node ospf6_node =
+static struct cmd_node ospf6_node =
 {
   OSPF6_NODE,
   "%s(config-ospf6)# "
 };
 
-struct cmd_node keychain_node =
+static struct cmd_node keychain_node =
 {
   KEYCHAIN_NODE,
   "%s(config-keychain)# "
 };
 
-struct cmd_node keychain_key_node =
+static struct cmd_node keychain_key_node =
 {
   KEYCHAIN_KEY_NODE,
   "%s(config-keychain-key)# "
