@@ -86,7 +86,7 @@ connected_announce (struct interface *ifp, struct connected *ifc)
 
       zebra_interface_address_add_update (ifp, ifc);
 
-      if (if_is_up(ifp))
+      if (if_is_operative(ifp))
         {
           if (ifc->address->family == AF_INET)
 	    connected_up_ipv4 (ifp, ifc);
@@ -318,6 +318,8 @@ connected_delete_ipv4 (struct interface *ifp, int flags, struct in_addr *addr,
     return;
     
   connected_withdraw (ifc);
+
+  rib_update();
 }
 
 #ifdef HAVE_IPV6
@@ -437,5 +439,7 @@ connected_delete_ipv6 (struct interface *ifp, struct in6_addr *address,
     return;
 
   connected_withdraw (ifc);
+
+  rib_update();
 }
 #endif /* HAVE_IPV6 */
